@@ -9,7 +9,7 @@ from typing import Dict, List, Optional, Tuple, TypedDict, Union
 import httpx
 import pandas as pd
 import requests
-from SPARQLWrapper import JSON, SPARQLWrapper
+from SPARQLWrapper import JSON, POST, SPARQLWrapper
 from strenum import StrEnum
 
 from cimsparql.async_sparql_wrapper import AsyncSparqlWrapper
@@ -140,6 +140,7 @@ class GraphDBClient:
 
     def _init_sparql_wrapper(self):
         self.sparql.setReturnFormat(JSON)
+        self.sparql.setMethod(POST)
         self.sparql.setCredentials(self.service_cfg.user, self.service_cfg.passwd)
         if self.service_cfg.timeout:
             self.sparql.setTimeout(self.service_cfg.timeout)
@@ -219,10 +220,9 @@ class GraphDBClient:
     def get_prefixes(self) -> Dict[str, str]:
         prefixes = default_namespaces()
 
-        if self.service_cfg.rest_api == RestApi.BLAZEGRAPH:
-            # Blazegraph does not expose prefixes over API
-            # When using Blazegraph custom prefixes must be added via `update_prefixes`
-            # By default we load a pre-defined set of prefixes
+        if self.service_cfg.rest_api in (RestApi.BLAZEGRAPH, RestApi.DIRECT_SPARQL_ENDPOINT):
+            # These APis does not expose prefixes. Custom prefixes must be added
+            # via `update_prefixes`. By default we load a pre-defined set of prefixes
             return prefixes
 
         auth = requests.auth.HTTPBasicAuth(self.service_cfg.user, self.service_cfg.passwd)
